@@ -11,7 +11,7 @@ our $server;
 @Template::Quick::Main::EXPORT_OK   = qw(all initMain Header Footer);
 %Template::Quick::Main::EXPORT_TAGS = ('all' => [qw(initMain Header Footer)]);
 @Template::Quick::Main::ISA         = qw( Exporter Template::Quick);
-$Template::Quick::Main::VERSION     = '0.34';
+$Template::Quick::Main::VERSION     = '0.35';
 $DefaultClass                       = 'Template::Quick::Main' unless defined $Template::Quick::Main::DefaultClass;
 
 =head1 NAME
@@ -39,11 +39,11 @@ L<CGI::CMS::GUI> L<Template::Quick>
 =cut
 
 sub new {
-        my ($class, @initializer) = @_;
-        my $self = {};
-        bless $self, ref $class || $class || $DefaultClass;
-        $self->initMain(@initializer) if(@initializer);
-        return $self;
+    my ($class, @initializer) = @_;
+    my $self = {};
+    bless $self, ref $class || $class || $DefaultClass;
+    $self->initMain(@initializer) if(@initializer);
+    return $self;
 }
 
 =head2 initMain()
@@ -69,19 +69,23 @@ sub new {
 =cut
 
 sub initMain {
-        my ($self, @p) = getSelf(@_);
-        my $hash = $p[0];
-        $server    = $hash->{server};
-        $style     = defined $hash->{style} ? $hash->{style} : 'Crystal';
-        $size      = defined $hash->{size} ? $hash->{size} : 16;
-        $title     = defined $hash->{title} ? $hash->{title} : '';
-        $zoom      = defined $hash->{zoom} ? $hash->{zoom} : '';
-        $login     = defined $hash->{login} ? $hash->{login} : '';
-        $right     = defined $hash->{right} ? $hash->{right} : 0;
-        $htmlright = defined $hash->{htmlright} ? $hash->{htmlright} : 2;
-        $template  = defined $hash->{template} ? $hash->{template} : "index.htm";
-        my %template = (path => $hash->{path}, style => $style, template => $template,);
-        $self->SUPER::initTemplate(\%template);
+    my ($self, @p) = getSelf(@_);
+    my $hash = $p[0];
+    $server    = $hash->{server};
+    $style     = defined $hash->{style} ? $hash->{style} : 'Crystal';
+    $size      = defined $hash->{size} ? $hash->{size} : 16;
+    $title     = defined $hash->{title} ? $hash->{title} : '';
+    $zoom      = defined $hash->{zoom} ? $hash->{zoom} : '';
+    $login     = defined $hash->{login} ? $hash->{login} : '';
+    $right     = defined $hash->{right} ? $hash->{right} : 0;
+    $htmlright = defined $hash->{htmlright} ? $hash->{htmlright} : 2;
+    $template  = defined $hash->{template} ? $hash->{template} : "index.htm";
+    my %template = (
+        path     => $hash->{path},
+        style    => $style,
+        template => $template,
+    );
+    $self->SUPER::initTemplate(\%template);
 }
 
 =head2 Header()
@@ -89,9 +93,19 @@ sub initMain {
 =cut
 
 sub Header {
-        my ($self, @p) = getSelf(@_);
-        my %header = (name => 'bodyHeader', size => $size, server => $server, style => $style, title => $title, login => $login, right => $right, htmlright => $htmlright, zoom => $zoom);
-        $self->SUPER::appendHash(\%header);
+    my ($self, @p) = getSelf(@_);
+    my %header = (
+        name      => 'bodyHeader',
+        size      => $size,
+        server    => $server,
+        style     => $style,
+        title     => $title,
+        login     => $login,
+        right     => $right,
+        htmlright => $htmlright,
+        zoom      => $zoom
+    );
+    $self->SUPER::appendHash(\%header);
 }
 
 =head2 Footer()
@@ -99,9 +113,13 @@ sub Header {
 =cut
 
 sub Footer {
-        my ($self, @p) = getSelf(@_);
-        my %footer = (name => 'bodyFooter', style => $style, zoom => $zoom);
-        $self->SUPER::appendHash(\%footer);
+    my ($self, @p) = getSelf(@_);
+    my %footer = (
+        name  => 'bodyFooter',
+        style => $style,
+        zoom  => $zoom
+    );
+    $self->SUPER::appendHash(\%footer);
 }
 
 =head1 PRIVAT
@@ -113,15 +131,15 @@ see L<HTML::Menu::TreeView>
 =cut
 
 sub getSelf {
-        return @_ if defined($_[0]) && (!ref($_[0])) && ($_[0] eq 'Template::Quick::Main');
-        return (defined($_[0]) && (ref($_[0]) eq 'Template::Quick::Main' || UNIVERSAL::isa($_[0], 'Template::Quick::Main'))) ? @_ : ($Template::Quick::Main::DefaultClass->new, @_);
+    return @_ if defined($_[0]) && (!ref($_[0])) && ($_[0] eq 'Template::Quick::Main');
+    return (defined($_[0]) && (ref($_[0]) eq 'Template::Quick::Main' || UNIVERSAL::isa($_[0], 'Template::Quick::Main'))) ? @_ : ($Template::Quick::Main::DefaultClass->new, @_);
 }
 
 =head1 AUTHOR
 
 Dirk Lindner <lze@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 LICENSE
 
 Copyright (C) 2008 by Hr. Dirk Lindner
 
